<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    version="1.0"
    xmlns:cmdbf="http://cmdbf.org/schema/1-0-0/datamodel"
    xmlns:xslt="http://xml.apache.org/xslt"
    xmlns:xalan="http://xml.apache.org/xalan"
	xmlns:CMDBfRegistrationHandler="xalan://com.ibm.eis.mdrr.testregistration.CMDBfRegistrationHandler"
	xmlns:InstanceId="xalan://com.ibm.eis.mdrr.testregistration.InstanceId"
    extension-element-prefixes="CMDBfRegistrationHandler">

    <xsl:output method="xml" indent="yes" xalan:indent-amount="3"/>
    
<!-- Handle registerRequest -->

    <xsl:template match="cmdbf:registerRequest">
    	<CMDBfRegistrationHandler:initialize/>
    	<cmdbf:registerResponse>
    		<xsl:for-each select="cmdbf:itemList/cmdbf:item">
   				<xsl:variable name="itemId" select="InstanceId:new(cmdbf:instanceId/cmdbf:mdrId, cmdbf:instanceId/cmdbf:localId)"/>
  				<xsl:variable name="errMsg" select="CMDBfRegistrationHandler:registerItem(cmdbf:record, $itemId)"/>
   				<xsl:call-template name="responseTemplate">
   					<xsl:with-param name="mdrId" select="cmdbf:instanceId/cmdbf:mdrId"/>
   					<xsl:with-param name="localId" select="cmdbf:instanceId/cmdbf:localId"/>
   					<xsl:with-param name="errMsg" select="$errMsg"/>
   				</xsl:call-template>
    		</xsl:for-each>
    		<xsl:for-each select="cmdbf:relationshipList/cmdbf:relationship">
   				<xsl:variable name="sourceId" select="InstanceId:new(cmdbf:source/cmdbf:mdrId, cmdbf:source/cmdbf:localId)"/>
		   		<xsl:variable name="targetId" select="InstanceId:new(cmdbf:target/cmdbf:mdrId, cmdbf:target/cmdbf:localId)"/>
		   		<xsl:variable name="relationshipId" select="InstanceId:new(cmdbf:instanceId/cmdbf:mdrId, cmdbf:instanceId/cmdbf:localId)"/>
		   		<xsl:variable name="errMsg" select="CMDBfRegistrationHandler:registerRelationship(cmdbf:record, $sourceId, $targetId, $relationshipId)"/>
				<xsl:call-template name="responseTemplate">
   					<xsl:with-param name="mdrId" select="cmdbf:instanceId/cmdbf:mdrId"/>
   					<xsl:with-param name="localId" select="cmdbf:instanceId/cmdbf:localId"/>
   					<xsl:with-param name="errMsg" select="$errMsg"/>
   				</xsl:call-template>
    		</xsl:for-each>
		</cmdbf:registerResponse>
    	<CMDBfRegistrationHandler:finish/>
    </xsl:template>


<!-- Handle deregisterRequest -->
	
    <xsl:template match="cmdbf:deregisterRequest">
    	<CMDBfRegistrationHandler:initialize/>
    	<cmdbf:deregisterResponse>
    		<xsl:for-each select="cmdbf:itemIdList/cmdbf:instanceId">
		   		<xsl:variable name="itemId" select="InstanceId:new(cmdbf:mdrId, cmdbf:localId)"/>
		   		<xsl:variable name="errMsg" select="CMDBfRegistrationHandler:deregisterItem($itemId)"/>
				<xsl:call-template name="responseTemplate">
   					<xsl:with-param name="mdrId" select="cmdbf:mdrId"/>
   					<xsl:with-param name="localId" select="cmdbf:localId"/>
   					<xsl:with-param name="errMsg" select="$errMsg"/>
   				</xsl:call-template>
    		</xsl:for-each>
    		<xsl:for-each select="cmdbf:relationshipIdList/cmdbf:instanceId">
		   		<xsl:variable name="relationshipId" select="InstanceId:new(cmdbf:mdrId, cmdbf:localId)"/>
		   		<xsl:variable name="errMsg" select="CMDBfRegistrationHandler:deregisterRelationship($relationshipId)"/>
				<xsl:call-template name="responseTemplate">
   					<xsl:with-param name="mdrId" select="cmdbf:mdrId"/>
   					<xsl:with-param name="localId" select="cmdbf:localId"/>
   					<xsl:with-param name="errMsg" select="$errMsg"/>
   				</xsl:call-template>
    		</xsl:for-each>
		</cmdbf:deregisterResponse>
    	<CMDBfRegistrationHandler:finish/>
    </xsl:template>

	<xsl:template name="responseTemplate">
		<xsl:param name="mdrId"/>
		<xsl:param name="localId"/>
		<xsl:param name="errMsg"/>
    	<cmdbf:instanceResponse>
    		<cmdbf:instanceId>
	    		<cmdbf:mdrId><xsl:value-of select="$mdrId"/></cmdbf:mdrId>
	    		<cmdbf:localId><xsl:value-of select="$localId"/></cmdbf:localId>
	    	</cmdbf:instanceId>
    		<xsl:choose>
    			<xsl:when test="$errMsg = ''">
    				<cmdbf:accepted/>
    			</xsl:when>
    			<xsl:otherwise>
    				<cmdbf:declined><xsl:value-of select="$errMsg"/></cmdbf:declined>
    			</xsl:otherwise>
    		</xsl:choose>
    	</cmdbf:instanceResponse>
	</xsl:template>
</xsl:stylesheet>
